@@ -1,4 +1,9 @@
-require(MASS)  # needed for ginv() function
+for(p in c("MASS")) {
+   if (length(grep(paste("^package:", p, "$", sep=""), search())) == 0) {
+      if (!require(p, quietly = TRUE, character.only=TRUE))
+      warning(paste("hwe.cc needs package `", p, "' to be fully functional; please install", sep=""))
+   }
+}
 
 #######################################################
 # Cox procedure
