@@ -29,7 +29,12 @@ getb0 <- function(p, X, b1, b2)
 
 masize <- function(model,opts, alpha=0.025, gamma=0.2)
 {
-   require(survival)
+   for(p in c("survival")) {
+      if (length(grep(paste("^package:", p, "$", sep=""), search())) == 0) {
+         if (!require(p, quietly = TRUE, character.only=TRUE))
+         warning(paste("masize needs package `", p, "' to be fully functional; please install", sep=""))
+      }
+   }
    linear <- paste("linear",1:4,sep="")
    logistic <- paste("logistic",1:5,sep="")
    poisson <- paste("poisson",1:9,sep="")
